@@ -19,12 +19,12 @@ import os
 import os.path
 
 PACKAGE    = "sabayon"
-VERSION    = "2.27.91"
-LOCALEDIR = "/usr/local/share/locale"
-DATADIR    = "/usr/local/share"
-SYSCONFDIR = "/usr/local/etc"
-LIBEXECDIR = "/usr/local/libexec"
-SBINDIR    = "/usr/local/sbin"
+VERSION    = "2.28.0"
+LOCALEDIR = "/gnome/usr/share/locale"
+DATADIR    = "/gnome/usr/share"
+SYSCONFDIR = "/gnome/usr/etc"
+LIBEXECDIR = "/gnome/usr/libexec"
+SBINDIR    = "/gnome/usr/sbin"
 
 GLADEDIR    = os.path.join (DATADIR, "sabayon", "glade")
 PROFILESDIR = os.path.join (SYSCONFDIR, "desktop-profiles")
